@@ -28,7 +28,7 @@ KBBLevelConfigurationWidget::KBBLevelConfigurationWidget(QWidget *parent, int c,
 	l->addWidget(kcfg_balls, 0, 0, 1, 2);
 	kcfg_balls->setMinimum(1);
 	kcfg_balls->setValue(b);
-	kcfg_balls->setSuffix(ki18ncp("A number between 1 and 99 is displayed in front of it.", " ball", " balls"));
+	kcfg_balls->setSuffix(ki18ncp("@item:valuesuffix to a number between 1 and 99", " ball", " balls"));
 	connect(kcfg_balls, static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &KBBLevelConfigurationWidget::boxSizeChanged);
 
 	kcfg_columns = new KPluralHandlingSpinBox(this);
@@ -37,7 +37,7 @@ KBBLevelConfigurationWidget::KBBLevelConfigurationWidget(QWidget *parent, int c,
 	kcfg_columns->setMinimum(2);
 	kcfg_columns->setMaximum(30);
 	kcfg_columns->setValue(c);
-	kcfg_columns->setSuffix(ki18ncp("A number between 2 and 30 is displayed in front of it.", " column", " columns"));
+	kcfg_columns->setSuffix(ki18ncp("@item:valuesuffix to a number between 2 and 30", " column", " columns"));
 	connect(kcfg_columns, static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &KBBLevelConfigurationWidget::boxSizeChanged);
 
 	kcfg_rows = new KPluralHandlingSpinBox(this);
@@ -46,7 +46,7 @@ KBBLevelConfigurationWidget::KBBLevelConfigurationWidget(QWidget *parent, int c,
 	kcfg_rows->setMinimum(2);
 	kcfg_rows->setMaximum(30);
 	kcfg_rows->setValue(r);
-	kcfg_rows->setSuffix(ki18ncp("A number between 2 and 30 is displayed in front of it.", " row", " rows"));
+	kcfg_rows->setSuffix(ki18ncp("@item:valuesuffix to a number between 2 and 30", " row", " rows"));
 	connect(kcfg_rows, static_cast<void (KPluralHandlingSpinBox::*)(int)>(&KPluralHandlingSpinBox::valueChanged), this, &KBBLevelConfigurationWidget::boxSizeChanged);
 
 	m_view = new KBBLevelConfigurationPreview(this, themeManager);
